import React, { Component } from "react";
import Button from "react-bootstrap/esm/Button";
import Card from 'react-bootstrap/Card';
import ListGroup from 'react-bootstrap/ListGroup';
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import DeleteUserModal from './DeleteUserModal'
import EditUser from './EditUser'
import CreateNewUser from './CreateNewUser'
import { LinkContainer } from "react-router-bootstrap";
import Nav from 'react-bootstrap/Nav';


import * as userManagementActions from '../actions/UserManagementActions'

const mapStateToProps = state => {
    return state;
}

const DISPLAY = {
    LIST: "list",
    EDIT: "edit",
    CREATE: "create"
}

class UserItem extends Component {
    constructor(props) {
        super(props);
        this.state = {
            displayingPage: DISPLAY.LIST,
            editingUser: null
        }

        this.MapAllUsers = this.MapAllUsers.bind(this);
        this.handleShowDeleteModal = this.handleShowDeleteModal.bind(this);
        this.handleClose = this.handleClose.bind(this);
        this.handleSwitchToList = this.handleSwitchToList.bind(this);
        this.handleShowCreatePage = this.handleShowCreatePage.bind(this);
    }

    handleShowDeleteModal(e, dialogModalData) {
        e.preventDefault();
        const { showDeleteUserModalAction } = this.props
        showDeleteUserModalAction(dialogModalData)
    }

    handleShowEditPage(e, user) {
        e.preventDefault();
        this.setState({ editingUser: user })
        this.setState({ displayingPage: DISPLAY.EDIT })
    }

    handleShowCreatePage(e) {
        e.preventDefault();
        this.setState({ displayingPage: DISPLAY.CREATE })
    }

    handleClose() {
        const { hideDeleteUserModalAction } = this.props;
        hideDeleteUserModalAction();
    }

    handleSwitchToList(e) {
        this.setState({ displayingPage: DISPLAY.LIST })
    }

    MapAllUsers() {
        const allUsers = this.props.userList
        if (allUsers) {
            var showDeleteUserModal = this.props.showDeleteUserModal
            if (showDeleteUserModal === undefined) {
                showDeleteUserModal = false
            }
            console.log("deleteModal:" + showDeleteUserModal)
            var users = allUsers.map(user => {
                let editButtonID = "EditButton" + user.userID
                let deleteButtonID = "DeleteButton" + user.userID
                let itemID = "UserItem" + user.userID
                let dialogData = {
                    dialogID: "DeleteDialogUser" + user.userID,
                    name: user.firstName + " " + user.lastName,
                    userID: user.userID
                }

                return (
                    <div key={user.userID}>
                        <DeleteUserModal />
                        <Card style={{ width: "18rem", background: '#ebebeb' }} id={itemID}>
                            <Card.Header>{user.firstName} {user.lastName}</Card.Header>
                            <ListGroup variant="flush">
                                <ListGroup.Item >User ID: {user.userID}</ListGroup.Item>
                                <ListGroup.Item >First Name: {user.firstName}</ListGroup.Item>
                                <ListGroup.Item >Last Name: {user.lastName}</ListGroup.Item>
                            </ListGroup>
                            <Card.Footer style={{ display: 'flex', justifyContent: 'space-evenly' }}>
                                <Button variant="primary" onClick={(e) => this.handleShowEditPage(e, user)} id={editButtonID} >Edit</Button>
                                <Button variant="primary" type="submit" onClick={(e) => this.handleShowDeleteModal(e, dialogData)} id={deleteButtonID} style={{ background: '#ffc800', color: 'black', border: 'none' }}>
                                    Delete
                                </Button>
                            </Card.Footer>
                        </Card>
                    </div>
                )
            })
            console.log(users)
            return users
        }
    }

    render() {
        var workspace
        console.log(this.MapAllUsers)
        switch (this.state.displayingPage) {
            case DISPLAY.LIST:
                workspace = <Button onClick={this.handleShowCreatePage}>
                    <img alt="Add-User-Button" src="https://cdn.icon-icons.com/icons2/933/PNG/512/round-add-button_icon-icons.com_72595.png" style={{ width: '2rem' }}></img>
                </Button>
                this.MapAllUsers()
                break
            case DISPLAY.CREATE:
                workspace = <CreateNewUser goBack={this.handleSwitchToList} />
                break
            case DISPLAY.EDIT:
                workspace = <EditUser goBack={this.handleSwitchToList} editUser={this.state.editingUser} />
                break
            default:
                workspace = <Button onClick={this.handleShowCreatePage}>
                    <img alt="Add-User-Button" src="https://cdn.icon-icons.com/icons2/933/PNG/512/round-add-button_icon-icons.com_72595.png" style={{ width: '2rem' }}></img>
                </Button>
                this.MapAllUsers()
        }
        return (
            <div >
                {workspace}
            </div>
        )
    }
}

const mapDispatchToProps = dispatch => bindActionCreators({
    showDeleteUserModalAction: userManagementActions.getShowDeleteUserModalAction,
    hideDeleteUserModalAction: userManagementActions.getHideDeleteUserModalAction
}, dispatch)

const ConnectedUserItems = connect(mapStateToProps, mapDispatchToProps)(UserItem)
export default ConnectedUserItems